Changelog
=========


1.0 (unreleased)
----------------

First public release:

- ``SplitSubversionURL`` namedtuple class
- ``change_svn_url`` function
- ``split_svn_url`` function (`guessing` the repository part)
- ``unsplit_svn_url`` function

[tobiasherp]
